@@ -13,7 +13,7 @@ from .static_embedding_util import static_embedding
 
 
 @spacy.registry.augmenters("token_dict_replace.v1")
-def create_token__dict_replace_augmenter(
+def create_token__dict_replace_augmenter_v1(
     level: float,
     replace: Union[Dict[str, List[str]], Dict[str, Dict[str, List[str]]]],
     ignore_casing: bool = True,
@@ -23,13 +23,17 @@ def create_token__dict_replace_augmenter(
     """Creates an augmenter swaps a token with its synonym based on a dictionary.
 
     Args:
-        level (float): Probability to replace token given that it is in synonym dictionary.
-        replace (Union[Dict[str, List[str]], Dict[str, Dict[str, List[str]]]]): A dictionary of
-            words and a list of their replacement (e.g. synonyms) or a dictionary denoting
-            replacement based on pos tag.
-        ignore_casing: When doing the lookup should the model ignore casing? Defaults to True.
-        getter (Callable[[Token], str], optional): A getter function to extract the POS-tag.
-        keep_titlecase (bool): Should the model keep the titlecase of the replaced word. Defaults to True.
+        level (float): Probability to replace token given that it is in synonym
+            dictionary.
+        replace (Union[Dict[str, List[str]], Dict[str, Dict[str, List[str]]]]): A
+            dictionary of words and a list of their replacement (e.g. synonyms) or a
+            dictionary denoting replacement based on pos tag.
+        ignore_casing(bool, optional): When doing the lookup should the model ignore
+            casing? Defaults to True.
+        getter (Callable[[Token], str], optional): A getter function to extract the
+            POS-tag.
+        keep_titlecase (bool): Should the model keep the titlecase of the replaced
+            word. Defaults to True.
 
     Returns:
         Callable[[Language, Example], Iterator[Example]]: The augmenter.
@@ -46,7 +50,7 @@ def create_token__dict_replace_augmenter(
             replace[k.lower()] = replace[k]
 
     return partial(
-        token_dict_replace_augmenter,
+        token_dict_replace_augmenter_v1,
         level=level,
         replace=replace,
         getter=getter,
@@ -55,7 +59,7 @@ def create_token__dict_replace_augmenter(
     )
 
 
-def token_dict_replace_augmenter(
+def token_dict_replace_augmenter_v1(
     nlp: Language,
     example: Example,
     level: float,
@@ -88,7 +92,7 @@ def token_dict_replace_augmenter(
 
 
 @spacy.registry.augmenters("wordnet_synonym.v1")
-def create_wordnet_synonym_augmenter(
+def create_wordnet_synonym_augmenter_v1(
     level: float,
     lang: Optional[str] = None,
     respect_pos: bool = True,
@@ -98,27 +102,32 @@ def create_wordnet_synonym_augmenter(
     """Creates an augmenter swaps a token with its synonym based on a dictionary.
 
     Args:
-        lang (Optional[str], optional): Language supplied a ISO 639-1 language code. Defaults to None,
-            in which case the lang is based on the language of the spacy nlp pipeline used.
-            Possible language codes include:
-            "da", "ca", "en", "eu", "fa", "fi", "fr", "gl", "he", "id", "it", "ja", "nn", "no", "pl", "pt", "es", "th".
-        level (float): Probability to replace token given that it is in synonym dictionary.
+        lang (Optional[str], optional): Language supplied a ISO 639-1 language code.
+            Defaults to None, in which case the lang is based on the language of the
+            spacy nlp pipeline used. Possible language codes include:
+            "da", "ca", "en", "eu", "fa", "fi", "fr", "gl", "he", "id", "it", "ja",
+            "nn", "no", "pl", "pt", "es", "th".
+        level (float): Probability to replace token given that it is in synonym
+            dictionary.
         respect_pos (bool, optional): Should POS-tag be respected? Defaults to True.
-        getter (Callable[[Token], str], optional): A getter function to extract the POS-tag.
-        keep_titlecase (bool): Should the model keep the titlecase of the replaced word. Defaults to True.
+        getter (Callable[[Token], str], optional): A getter function to extract the
+            POS-tag.
+        keep_titlecase (bool): Should the model keep the titlecase of the replaced
+            word. Defaults to True.
 
     Returns:
         Callable[[Language, Example], Iterator[Example]]: The augmenter.
 
     Example:
-        >>> english_synonym_augmenter = create_wordnet_synonym_augmenter(level=0.1, lang="en")
+        >>> english_synonym_augmenter = create_wordnet_synonym_augmenter(level=0.1,
+        >>>                                                              lang="en")
     """
     init_wordnet()
     from nltk.corpus import wordnet
     from .wordnet_util import upos_wn_dict
     from .wordnet_util import lang_wn_dict
 
-    def wordnet_synonym_augmenter(
+    def wordnet_synonym_augmenter_v1(
         nlp: Language,
         example: Example,
         level: float,
@@ -162,7 +171,7 @@ def create_wordnet_synonym_augmenter(
     if lang:
         lang = lang_wn_dict[lang]
     return partial(
-        wordnet_synonym_augmenter,
+        wordnet_synonym_augmenter_v1,
         level=level,
         lang=lang,
         getter=getter,
@@ -171,7 +180,7 @@ def create_wordnet_synonym_augmenter(
     )
 
 
-def token_replace_augmenter(
+def token_replace_augmenter_v1(
     nlp: Language,
     example: Example,
     level: float,
@@ -199,16 +208,19 @@ def token_replace_augmenter(
 
 
 @spacy.registry.augmenters("token_replace.v1")
-def create_token_replace_augmenter(
+def create_token_replace_augmenter_v1(
     replace: Callable[[Token], str],
     keep_titlecase: bool = True,
 ) -> Callable[[Language, Example], Iterator[Example]]:
     """Creates an augmenter which replaces a token based on a replace function.
 
     Args:
-        level (float): Probability to replace token given that it is in synonym dictionary.
-        replace (Callable[[Token], str): A callable which takes a spaCy Token as input and returns the replaces word as a string.
-        keep_titlecase (bool, optional): If original text was uppercased cased should replaces text also be? Defaults to True.
+        level (float): Probability to replace token given that it is in synonym
+            dictionary.
+        replace (Callable[[Token], str): A callable which takes a spaCy Token as input
+            and returns the replaces word as a string.
+        keep_titlecase (bool, optional): If original text was uppercased cased should
+            replaces text also be? Defaults to True.
 
     Returns:
         Callable[[Language, Example], Iterator[Example]]: The augmenter.
@@ -218,15 +230,15 @@ def create_token_replace_augmenter(
         ...    vowels = ['a','e','i','o','u', 'y']
         ...    non_vowels = [c for c in token.text if c.lower() not in vowels]
         ...    return ''.join(non_vowels)
-        >>> remove_vowel_augmenter = create_token_replace_augmenter(replace=remove_vowels, level=.10)
+        >>> aug = create_token_replace_augmenter(replace=remove_vowels, level=.10)
     """
     return partial(
-        token_replace_augmenter, replace=replace, keep_titlecase=keep_titlecase
+        token_replace_augmenter_v1, replace=replace, keep_titlecase=keep_titlecase
     )
 
 
 @spacy.registry.augmenters("word_embedding.v1")
-def create_word_embedding_augmenter(
+def create_word_embedding_augmenter_v1(
     level=float,
     n: int = 10,
     nlp: Optional[Language] = None,
@@ -236,11 +248,17 @@ def create_word_embedding_augmenter(
     """Creates an augmenter which replaces a token based on a replace function.
 
     Args:
-        level (float): Probability to replace token given that it is in synonym dictionary.
-        n (int, optional): Number of most similar word vectors to sample from
-        nlp (Optional[Language], optional): A spaCy text-processing pipeline used for supplying the word vectors if the nlp model supplies doesn't contain word vectors.
-        keep_titlecase (bool, optional): If original text was uppercased cased should replaces text also be? Defaults to True.
-        ignore_case (bool, optional): The word embedding augmenter does not replace a word with the same word. Should this operation ignore casing? Default to True.
+        level (float): Probability to replace token given that it is in synonym
+            dictionary.
+        n (int, optional): Number of most similar word vectors to sample from nlp
+            (Optional[Language], optional): A spaCy text-processing pipeline used for
+            supplying the word vectors if the nlp model supplies doesn't contain word
+            vectors.
+        keep_titlecase (bool, optional): If original text was uppercased cased should
+            replaces text also be? Defaults to True.
+        ignore_case (bool, optional): The word embedding augmenter does not replace a
+            word with the same word. Should this operation ignore casing? Default to
+            True.
 
     Returns:
         Callable[[Language, Example], Iterator[Example]]: The augmenter.
@@ -256,7 +274,10 @@ def create_word_embedding_augmenter(
             embedding.update_from_vocab(t.doc.vocab)
         if embedding.vocab.vectors.shape == (0, 0):
             raise ValueError(
-                "Vectors are empty. Typically this is due to using a transformer-based or small spaCy model. Specify nlp for the create_word_embedding_augmenter to a spaCy pipeline with static word embedding to avoid this issue."
+                "Vectors are empty. Typically this is due to using a transformer-based "
+                + "or small spaCy model. Specify nlp for the "
+                + "create_word_embedding_augmenter to a spaCy pipeline with static word"
+                + " embedding to avoid this issue."
             )
         if t.text in embedding:
             rep = embedding.most_similar(t.text, n=n + 2)
@@ -272,7 +293,7 @@ def create_word_embedding_augmenter(
 
     __replace = partial(replace, n=n, ignore_casing=ignore_casing, embedding=embedding)
     return partial(
-        token_replace_augmenter,
+        token_replace_augmenter_v1,
         replace=__replace,
         keep_titlecase=keep_titlecase,
         level=level,
